==> taxware-chestnut-check-model-1.0.0-20230329.013051-47-sources.jar: com/xforceplus/taxware/chestnut/check/model/base/TaxpayerInfo.java <==
package com.xforceplus.taxware.chestnut.check.model.base;


import lombok.Data;

import java.util.Date;

/**
 * @Auther lv
 * @Date 2023/2/20
 */
@Data
public class TaxpayerInfo {

    /**
     * 纳税人识别号/统一社会信用代码
     */
    private String taxNo;

    /**
     * 开票方纳税人状态
     * 01：受理
     * 02：筹建期
     * 03：正常
     * 04：停业
     * 05：非正常
     * 06：清算
     * 07：注销
     * 08：非正常户注销
     * 09：报验
     * 10：核销报验
     * 11：中断缴费
     * 12：恢复缴费
     * 13：简易注销无异议
     * 99：其他
     */
    private String sellerTaxpayerStatus;

    /**
     * 登记序号（非必须）
     */
    private String registerNo;

    /**
     * 税收档案编号（非必须）
     */
    private String taxArchivesNo;

    /**
     * 纳税人名称
     */
    private String taxpayerName;

    /**
     * 纳税人类型标签
     * 1：一般纳税人
     * 2：小规模纳税人
     * 3：转登记小规模纳税人
     * 4：辅导期一般纳税人
     * 5：自然人
     */
    private String taxpayerTypeTag;

    /**
     * 生产经营地址
     */
    private String productionAddress;

    /**
     * 注册地邮政编码
     */
    private String postalCode;

    /**
     * 注册地联系电话（非必须）
     */
    private String registerTel;

    /**
     * 法人名称(法定代表人姓名）
     */
    private String legalPersonName;

    /**
     * 登记注册类型（国标，非必须）
     */
    private String registerType;

    /**
     * 行业代码
     * 主行业代码特定征收部门可空
     */
    private String industryCode;

    /**
     * 区县级税务机关代码
     */
    private String countyTaxAuthorityCode;

    /**
     * 税务机关代码
     * 主管税务所科分局
     */
    private String chargeTaxDepartmentCode;

    /**
     * 税务机关名称
     * 主管税务所科分局
     */
    private String chargeTaxDepartmentName;

    /**
     * 财务负责人姓名
     */
    private String financialDirectorName;

    /**
     * 账户名称
     */
    private String accountName;

    /**
     * 账号（非必须）
     * 首选账户账号
     */
    private String account;

    /**
     * 企业办税人员姓名（非必须）
     */
    private String enterpriseTaxPersonnelName;

    /**
     * 新电票试点企业标识
     * Y：新电票试点企业
     * N：不是新电票试点企业
     */
    private String allElectricFlag;

    /**
     * 出口企业分类
     * 空：非出口企业
     * 01：一类出口企业
     * 02：二类出口企业
     * 03：三类出口企业
     * 04：四类出口企业
     */
    private String exportEnterprisesType;

    /**
     * 总分机构类型
     * 0：非总分机构
     * 1：总机构
     * 2：分支机构
     * 3：分总机构
     */
    private String organizationType;

    /**
     * 银行营业网点（非必须）
     */
    private String bankBusinessOutlets;

    /**
     * 纳税人类型标签有效期起（非必须）
     * 格式：
     * yyyy-MM-dd
     */
    private Date startTaxpayerTypeFlagDate;

    /**
     * 纳税人类型标签有效期止（非必须）
     * 格式：
     * yyyy-MM-dd
     */
    private Date endTaxpayerTypeFlagDate;

    /**
     * 企业行业性质（非必须）
     * 01：成品油生产企业
     * 02：成品油经销企业
     * 03：国内机动车生产企业 04：进口机动车生产企业驻我国办事机构或总授权代理机构 05：机动车授权经销企业 06：其他机动车贸易商 07：二手车市场
     * 08：二手车经销企业
     * 09：二手车拍卖企业 10：稀土矿产企业
     * 11：稀土冶炼分离企业 12：稀土其他企业
     * 13：稀土矿产企业、稀土冶炼分离企业、稀土其他企业
     * 14：稀土矿产企业、稀土冶炼分离企业 15：稀土矿产企业、稀土其他企业
     * 16：稀土冶炼分离企业、稀土其他企业 17：卷烟生产企业
     * 18：卷烟批发企业
     * 19：卷烟出口企业
     * 20：生产型出口企业
     * 21：外贸型出口企业
     * 22：外贸综合服务企业 23：自贸区试点企业
     * 24：特殊监管区内企业 25：增值税一般纳税人资格试点
     * 26：市场采购试点
     * 27：退税商店 28：电子商务出口企业 29：享受出口退税政策的融资租赁企业
     * 30：增值税零税率应税服务提供者 31：房地产开发企业
     * 32：农产品深加工企业 33：外购石脑油、燃料油用于消费税退税企业
     * 34：从事机动车进口的其他贸易商 35：自产农产品者
     * 36：农产品收购企业
     * 37：光伏收购企业
     * 38：住房租赁企业
     * 39：冬奥会退税企业
     */
    private String industryNatureProperties;

    /**
     * 消费税纳税人类型（非必须）
     * 01：卷烟生产消费税纳税人
     * 02：卷烟批发消费税纳税人
     * 03：白酒生产消费税纳税人
     * 04：黄酒生产消费税纳税人
     * 05：啤酒生产消费税纳税人
     * 06：其他酒生产消费税纳税人
     * 07：小汽车生产消费税纳税人
     * 08：超豪华小汽车消费税纳税人
     * 09：汽油生产消费税纳税人
     * 10：石脑油生产消费税纳税人
     * 11：溶剂油生产消费税纳税人
     * 12：润滑油生产消费税纳税人
     * 13：柴油生产消费税纳税人
     * 14：航空煤油生产消费税纳税人
     * 15：燃料油生产消费税纳税人
     * 16：电池生产消费税纳税人
     * 17：涂料生产消费税纳税人
     * 18：高档化妆品生产消费税纳税人 19：金银首饰铂金首饰和钻石及钻石饰品零售消费税纳税人 20：其他贵重首饰和珠宝玉石生产消费税纳税人 21：鞭炮焰火生产消费税纳税人
     * 22：摩托车生产消费税纳税人
     * 23：高尔夫球及球具生产消费税纳税人
     * 24：高档手表生产消费税纳税人
     * 25：游艇生产消费税纳税人
     * 26：木制一次性筷子生产消费税纳税人
     * 27：实木地板生产消费税纳税人
     * 28：雪茄烟生产消费税纳税人
     * 29：烟丝生产消费税纳税人
     */
    private String exciseTaxpayerType;
}

==> taxware-chestnut-check-model-1.0.0-20230413.102602-56-sources.jar: com/xforceplus/taxware/chestnut/check/model/base/TaxpayerInfo.java <==
package com.xforceplus.taxware.chestnut.check.model.base;


import lombok.Data;

/**
 * @Auther lv
 * @Date 2023/2/20
 */
@Data
public class TaxpayerInfo {

    /**
     * 纳税人识别号/统一社会信用代码
     */
    private String taxNo;

    /**
     * 开票方纳税人状态
     * 01：受理
     * 02：筹建期
     * 03：正常
     * 04：停业
     * 05：非正常
     * 06：清算
     * 07：注销
     * 08：非正常户注销
     * 09：报验
     * 10：核销报验
     * 11：中断缴费
     * 12：恢复缴费
     * 13：简易注销无异议
     * 99：其他
     */
    private String sellerTaxpayerStatus;

    /**
     * 登记序号（非必须）
     */
    private String registerNo;

    /**
     * 税收档案编号（非必须）
     */
    private String taxArchivesNo;

    /**
     * 纳税人名称
     */
    private String taxpayerName;

    /**
     * 纳税人类型标签
     * 1：一般纳税人
     * 2：小规模纳税人
     * 3：转登记小规模纳税人
     * 4：辅导期一般纳税人
     * 5：自然人
     */
    private String taxpayerTypeTag;

    /**
     * 生产经营地址
     */
    private String productionAddress;

    /**
     * 注册地邮政编码
     */
    private String postalCode;

    /**
     * 注册地联系电话（非必须）
     */
    private String registerTel;

    /**
     * 法人名称(法定代表人姓名）
     */
    private String legalPersonName;

    /**
     * 登记注册类型（国标，非必须）
     */
    private String registerType;

    /**
     * 行业代码
     * 主行业代码特定征收部门可空
     */
    private String industryCode;

    /**
     * 区县级税务机关代码
     */
    private String countyTaxAuthorityCode;

    /**
     * 税务机关代码
     * 主管税务所科分局
     */
    private String chargeTaxDepartmentCode;

    /**
     * 税务机关名称
     * 主管税务所科分局
     */
    private String chargeTaxDepartmentName;

    /**
     * 财务负责人姓名
     */
    private String financialDirectorName;

    /**
     * 账户名称
     */
    private String accountName;

    /**
     * 账号（非必须）
     * 首选账户账号
     */
    private String account;

    /**
     * 企业办税人员姓名（非必须）
     */
    private String enterpriseTaxPersonnelName;

    /**
     * 新电票试点企业标识
     * Y：新电票试点企业
     * N：不是新电票试点企业
     */
    private String allElectricFlag;

    /**
     * 出口企业分类
     * 空：非出口企业
     * 01：一类出口企业
     * 02：二类出口企业
     * 03：三类出口企业
     * 04：四类出口企业
     */
    private String exportEnterprisesType;

    /**
     * 总分机构类型
     * 0：非总分机构
     * 1：总机构
     * 2：分支机构
     * 3：分总机构
     */
    private String organizationType;

    /**
     * 银行营业网点（非必须）
     */
    private String bankBusinessOutlets;

    /**
     * 纳税人类型标签有效期起（非必须）
     * 格式：
     * yyyy-MM-dd
     */
    private String startTaxpayerTypeFlagDate;

    /**
     * 纳税人类型标签有效期止（非必须）
     * 格式：
     * yyyy-MM-dd
     */
    private String endTaxpayerTypeFlagDate;

    /**
     * 企业行业性质（非必须）
     * 01：成品油生产企业
     * 02：成品油经销企业
     * 03：国内机动车生产企业 04：进口机动车生产企业驻我国办事机构或总授权代理机构 05：机动车授权经销企业 06：其他机动车贸易商 07：二手车市场
     * 08：二手车经销企业
     * 09：二手车拍卖企业 10：稀土矿产企业
     * 11：稀土冶炼分离企业 12：稀土其他企业
     * 13：稀土矿产企业、稀土冶炼分离企业、稀土其他企业
     * 14：稀土矿产企业、稀土冶炼分离企业 15：稀土矿产企业、稀土其他企业
     * 16：稀土冶炼分离企业、稀土其他企业 17：卷烟生产企业
     * 18：卷烟批发企业
     * 19：卷烟出口企业
     * 20：生产型出口企业
     * 21：外贸型出口企业
     * 22：外贸综合服务企业 23：自贸区试点企业
     * 24：特殊监管区内企业 25：增值税一般纳税人资格试点
     * 26：市场采购试点
     * 27：退税商店 28：电子商务出口企业 29：享受出口退税政策的融资租赁企业
     * 30：增值税零税率应税服务提供者 31：房地产开发企业
     * 32：农产品深加工企业 33：外购石脑油、燃料油用于消费税退税企业
     * 34：从事机动车进口的其他贸易商 35：自产农产品者
     * 36：农产品收购企业
     * 37：光伏收购企业
     * 38：住房租赁企业
     * 39：冬奥会退税企业
     */
    private String industryNatureProperties;

    /**
     * 消费税纳税人类型（非必须）
     * 01：卷烟生产消费税纳税人
     * 02：卷烟批发消费税纳税人
     * 03：白酒生产消费税纳税人
     * 04：黄酒生产消费税纳税人
     * 05：啤酒生产消费税纳税人
     * 06：其他酒生产消费税纳税人
     * 07：小汽车生产消费税纳税人
     * 08：超豪华小汽车消费税纳税人
     * 09：汽油生产消费税纳税人
     * 10：石脑油生产消费税纳税人
     * 11：溶剂油生产消费税纳税人
     * 12：润滑油生产消费税纳税人
     * 13：柴油生产消费税纳税人
     * 14：航空煤油生产消费税纳税人
     * 15：燃料油生产消费税纳税人
     * 16：电池生产消费税纳税人
     * 17：涂料生产消费税纳税人
     * 18：高档化妆品生产消费税纳税人 19：金银首饰铂金首饰和钻石及钻石饰品零售消费税纳税人 20：其他贵重首饰和珠宝玉石生产消费税纳税人 21：鞭炮焰火生产消费税纳税人
     * 22：摩托车生产消费税纳税人
     * 23：高尔夫球及球具生产消费税纳税人
     * 24：高档手表生产消费税纳税人
     * 25：游艇生产消费税纳税人
     * 26：木制一次性筷子生产消费税纳税人
     * 27：实木地板生产消费税纳税人
     * 28：雪茄烟生产消费税纳税人
     * 29：烟丝生产消费税纳税人
     */
    private String exciseTaxpayerType;
}
